@@ -1,5 +1,5 @@
 /*
-  $Id: MbtServerBase.h 9079 2011-03-23 10:23:42Z sloot $
+  $Id: MbtServerBase.h 13574 2011-11-24 14:23:00Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/MbtServer/include/mbtserver/MbtServerBase.h $
 
   Copyright (c) 1998 - 2011
@@ -34,15 +34,16 @@
 #include "timbl/LogStream.h"
 #include "timblserver/SocketBasics.h"
 
-namespace Tagger {
-  class MbtServer {
+namespace MbtServer {
+
+  class MbtServerClass {
     friend class TaggerClass;
     friend void *tagChild( void * );
   public:
     LogStream cur_log;
-    virtual ~MbtServer();
+    virtual ~MbtServerClass();
     static std::string VersionInfo( bool );
-    MbtServer( Timbl::TimblOpts& );
+    MbtServerClass( Timbl::TimblOpts& );
     void RunServer();
     void createServers();
   protected:
@@ -55,6 +56,8 @@ namespace Tagger {
   private:
     int maxConn;
     int serverPort;
+    size_t accCount;
+    size_t rejCount;
     LogLevel dbLevel;
     Sockets::ServerSocket *tcp_socket;
     std::string configFile;
