@@ -1,5 +1,5 @@
 /*
-  $Id: MbtServer.cxx 9079 2011-03-23 10:23:42Z sloot $
+  $Id: MbtServer.cxx 9330 2011-04-07 13:06:17Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/MbtServer/src/MbtServer.cxx $
   Copyright (c) 1998 - 2011
   ILK   - Tilburg University
@@ -31,7 +31,7 @@
 
 int main(int argc, char *argv[]) {
   TimblOpts opts( argc, argv );
-  Tagger::StartServer( opts );   
+  MbtServer::StartServer( opts );   
   exit(EXIT_SUCCESS);
 }
 
